import React from 'react'
import { translate } from 'cozy-ui/react/I18n'
import Tabs from 'components/CommonKit/Tabs/StyledBlueTabs'
import Tab from 'components/CommonKit/Tabs/StyledBlueTab'
import { SelectView } from 'services/dataChallengeContracts'

interface ChallengeNavigatorProps {
  selectedView: SelectView
  handleClickSelectView(selectView: SelectView): void
  t: Function
}

const ChallengeNavigator: React.FC<ChallengeNavigatorProps> = ({
  selectedView,
  handleClickSelectView,
  t,
}: ChallengeNavigatorProps) => {
  // const view = SelectView[selectedView[0]]
  const handleClick = (selectedView: SelectView) => {
    handleClickSelectView(selectedView)
  }

  const defineNavTab = () => {
    return [SelectView.BADGES, SelectView.ECOGESTURES]
  }

  const defineLabel = (inputSelectedView: SelectView) => {
    const classes =
      inputSelectedView === selectedView ? `tab-text-on` : `tab-text-off`
    return (
      <span className={classes}>
        {t(`Nav.${SelectView[inputSelectedView]}`)}
      </span>
    )
  }

  return (
    <div className="cn">
      <Tabs className="cn-tabs" value={selectedView} variant="fullWidth">
        {defineNavTab().map((inputSelectedView, index) => {
          return (
            <Tab
              className="cn-tab"
              key={index}
              value={inputSelectedView}
              label={defineLabel(inputSelectedView)}
              onClick={() => handleClick(inputSelectedView)}
            />
          )
        })}
      </Tabs>
    </div>
  )
}

export default translate()(ChallengeNavigator)
