import React from 'react'
import { translate } from 'cozy-ui/react/I18n'
import { DateTime, Interval } from 'luxon'
import warning from 'assets/icons/ico/warning.svg'
import StyledIcon from 'components/CommonKit/Icon/StyledIcon'

interface ErrorDataConsumptionVisualizerProps {
  lastDateWithAllData: DateTime
  t: Function // translation service
  handleChangeIndex: (index: number) => void
  indexDisplayed: number
  setSelectedDate: Function
  setIndexDisplayed: Function
  date: DateTime
}
const ErrorDataConsumptionVisualizer = ({
  lastDateWithAllData,
  t,
  date,
  indexDisplayed,
  setIndexDisplayed,
  setSelectedDate,
}: ErrorDataConsumptionVisualizerProps) => {
  const setDateAndMoveToindex = () => {
    let indexToMove = 0
    if (date < lastDateWithAllData) {
      indexToMove = -(
        Interval.fromDateTimes(date, lastDateWithAllData).count('weeks') - 1
      )
    } else {
      indexToMove =
        Interval.fromDateTimes(lastDateWithAllData, date).count('weeks') - 1
    }
    if (indexToMove !== 0) {
      setIndexDisplayed(indexDisplayed + indexToMove)
    }
    setSelectedDate(lastDateWithAllData)
  }

  return (
    <div onClick={() => setDateAndMoveToindex()} className="error-line">
      <StyledIcon icon={warning} size={22} className="warning-icon" />
      <span className={`text-16-normal underlined-error`}>
        {`${t('COMMON.LASTVALIDDATA')} : ${lastDateWithAllData.toFormat(
          "dd'/'MM'/'yy"
        )}`}
      </span>
    </div>
  )
}

export default translate()(ErrorDataConsumptionVisualizer)
